spoon.nulllogger

Package spoon :: Module nulllogger |
[hide private]
[frames] | no frames]

# Source Code for Module spoon.nulllogger

     1  #
     2  # Copyright (C) 2006, Matt Sullivan <matts@zarrf.com>
     3  #
     4  # Permission is hereby granted, free of charge, to any person obtaining
     5  # a copy of this software and associated documentation files (the
     6  # "Software"), to deal in the Software without restriction, including
     7  # without limitation the rights to use, copy, modify, merge, publish,
     8  # distribute, sublicense, and/or sell copies of the Software, and to
     9  # permit persons to whom the Software is furnished to do so, subject to
    10  # the following conditions:
    11  #
    12  # The above copyright notice and this permission notice shall be included
    13  # in all copies or substantial portions of the Software.
    14  #
    15  # THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
    16  # OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
    17  # MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
    18  # IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
    19  # CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
    20  # TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
    21  # SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
    22  #
    23
    24 -class NullLogger(object):
    25      """
    26      Dummy logging object.  Doesn't do anything.
    27      """
    28 -    def debug(self, msg, *args, **kwargs):
    29          pass
    30 -    def info(self, msg, *args, **kwargs):
    31          pass
    32 -    def warning(self, msg, *args, **kwargs):
    33          pass
    34 -    def error(self, msg, *args, **kwargs):
    35          pass
    36 -    def critical(self, msg, *args, **kwargs):
    37          pass
    38 -    def log(self, lvl, msg, *args, **kwargs):
    39          pass
    40 -    def exception(self, msg, *args):
    41          pass
    42